@@ -8,12 +8,12 @@
         dplyr::group_by(.data[["label"]]) |>
         dplyr::group_map(function(data, name) {
             ts_median <- dplyr::bind_rows(data[["time_series"]]) |>
-                dplyr::group_by(.data[["Index"]]) |>
+                dplyr::group_by(dplyr::all_of("Index")) |>
                 dplyr::summarize(dplyr::across(dplyr::everything(),
                     stats::median,
                     na.rm = TRUE
                 )) |>
-                dplyr::select(-.data[["Index"]])
+                dplyr::select(-dplyr::all_of("Index"))
 
             ts_median["label"] <- name
             ts_median
