@@ -117,7 +117,7 @@ sits_labels.default <- function(data) {
     UseMethod("sits_labels<-", data)
 }
 #' @title Change the labels of a set of time series
-#' @param  data      Data cube or time series.
+#' @param  data      Time series.
 #' @param  value     A character vector used to convert labels. Labels will
 #'                   be renamed to the respective value positioned at the
 #'                   labels order returned by \code{\link{sits_labels}}.
@@ -139,8 +139,8 @@ sits_labels.default <- function(data) {
     data[["label"]] <- value[data[["label"]]]
     data
 }
-#' @title Change the labels of a set of time series
-#' @param  data      Data cube or time series.
+#' @title Change the labels of a probs raster cube
+#' @param  data      Raster cube with probability values.
 #' @param  value     A character vector used to convert labels. Labels will
 #'                   be renamed to the respective value positioned at the
 #'                   labels order returned by \code{\link{sits_labels}}.
@@ -156,8 +156,8 @@ sits_labels.default <- function(data) {
     data[["labels"]] <- list(value)
     data
 }
-#' @title Change the labels of a set of time series
-#' @param  data      Data cube or time series.
+#' @title Change the labels of a classified raster cube
+#' @param  data      Classified raster data cube.
 #' @param  value     A character vector used to convert labels. Labels will
 #'                   be renamed to the respective value positioned at the
 #'                   labels order returned by \code{\link{sits_labels}}.
@@ -178,7 +178,109 @@ sits_labels.default <- function(data) {
         row
     })
 }
-#' @title Change the labels of a set of time series
+#' @title Change the labels of a probs vector data cube
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @param  data      Probs vector data cube.
+#' @param  value     A character vector used to convert labels.
+#'
+#' @description
+#' A "probs_vector_cube" is a data cube with a set of segments that
+#' contain the probability values of each class for each polygon.
+#' When a user changes the labels of the class, this function
+#' modifies the labels associated to the cube's metadata and
+#' also changes the names in the segments file. The GPKG file
+#' containing the segments and the probability values is replace
+#' with a new file with the desired labels.
+#'
+#' @export
+`sits_labels<-.probs_vector_cube` <- function(data, value) {
+
+    # get the labels for the vector cube
+    labels_orig <- .cube_labels(data)
+    # check if value and labels match
+    .check_chr_parameter(value,
+                         len_max = length(labels_orig),
+                         len_min = length(labels_orig)
+    )
+    # check if there are no NA
+    .check_that(!anyNA(value))
+    # check if there are empty strings
+    .check_that(any(trimws(value) != ""))
+    # name the conversion vector with the original labels
+    names(labels_orig) <- value
+
+    # run for each tile of the cube
+    slider::slide_dfr(data, function(row){
+        # change the labels in the tile
+        row[["labels"]] <- list(value)
+        # read the segments for the tile
+        .segments <- .segments_read_vec(row)
+        # rename column names
+        .segments <- dplyr::rename(.segments, dplyr::all_of(labels_orig))
+        # Prepare and save results as vector
+        .vector_write_vec(
+            v_obj = .segments,
+            file_path = .segments_path(row),
+            append = FALSE
+        )
+        row
+    })
+}
+#' @title Change the labels of a class vector data cube
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @param  data      Class vector data cube.
+#' @param  value     A character vector used to convert labels.
+#'
+#' @description
+#' A "class_vector_cube" is a data cube with a set of segments that
+#' contain the probability values of each class for each polygon
+#' and also list the most probable class.
+#' When a user changes the labels of the class, this function
+#' modifies the labels associated to the cube's metadata and
+#' also changes the names in the segments file. The GPKG file
+#' containing the segments and the probability values is replace
+#' with a new file with the desired labels.
+#'
+#' @export
+`sits_labels<-.class_vector_cube` <- function(data, value) {
+
+    # get the labels for the vector cube
+    labels_orig <- .cube_labels(data)
+    # check if value and labels match
+    .check_chr_parameter(value,
+                         len_max = length(labels_orig),
+                         len_min = length(labels_orig)
+    )
+    # check if there are no NA
+    .check_that(!anyNA(value))
+    # check if there are empty strings
+    .check_that(any(trimws(value) != ""))
+    # name the conversion vector with the original labels
+    names(labels_orig) <- value
+    # create a named vector to map the class values
+    names(value) <- unname(labels_orig)
+
+    # run for each tile of the cube
+    slider::slide_dfr(data, function(row){
+        # change the labels in the tile
+        row[["labels"]] <- list(value)
+        # read the segments for the tile
+        # rename column names
+        # rename values in "class" column
+        .segments <- .segments_read_vec(row) |>
+            dplyr::rename(dplyr::all_of(labels_orig)) |>
+            dplyr::mutate(class = value[.data[["class"]]] )
+
+        # Save results in the segments file
+        .vector_write_vec(
+            v_obj = .segments,
+            file_path = .segments_path(row),
+            append = FALSE
+        )
+        row
+    })
+}
+#' @title Change the labels of other data structures
 #' @param  data      Data cube or time series.
 #' @param  value     A character vector used to convert labels. Labels will
 #'                   be renamed to the respective value positioned at the
