@@ -1,4 +1,3 @@
-
 test_that("Creating LS5-SR cubes from DEA", {
     landsat_cube <- .try(
         {
@@ -6,7 +5,7 @@ test_that("Creating LS5-SR cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "LS5-SR",
                 bands = c("B05", "CLOUD"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -21,7 +20,7 @@ test_that("Creating LS5-SR cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(landsat_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(landsat_cube) %in% c("B05", "CLOUD")))
@@ -30,9 +29,9 @@ test_that("Creating LS5-SR cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(landsat_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(landsat_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating LS7-SR cubes from DEA", {
@@ -42,7 +41,7 @@ test_that("Creating LS7-SR cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "LS7-SR",
                 bands = c("B05", "CLOUD"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -57,7 +56,7 @@ test_that("Creating LS7-SR cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(landsat_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(landsat_cube) %in% c("B05", "CLOUD")))
@@ -66,9 +65,9 @@ test_that("Creating LS7-SR cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(landsat_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(landsat_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating LS8-SR cubes from DEA", {
@@ -78,7 +77,7 @@ test_that("Creating LS8-SR cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "LS8-SR",
                 bands = c("B05", "CLOUD"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -93,7 +92,7 @@ test_that("Creating LS8-SR cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(landsat_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(landsat_cube) %in% c("B05", "CLOUD")))
@@ -102,9 +101,9 @@ test_that("Creating LS8-SR cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(landsat_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(landsat_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating LS9-SR cubes from DEA", {
@@ -114,7 +113,7 @@ test_that("Creating LS9-SR cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "LS9-SR",
                 bands = c("B05", "CLOUD"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -129,7 +128,7 @@ test_that("Creating LS9-SR cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(landsat_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(landsat_cube) %in% c("B05", "CLOUD")))
@@ -138,9 +137,9 @@ test_that("Creating LS9-SR cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(landsat_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(landsat_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating S2 cubes from DEA using ROI", {
@@ -166,7 +165,7 @@ test_that("Creating S2 cubes from DEA using ROI", {
     )
 
     testthat::skip_if(purrr::is_null(dea_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(dea_cube) %in% c("B01", "B04", "B05")))
@@ -183,7 +182,7 @@ test_that("Creating S2 cubes from DEA using tiles", {
                 source = "DEAFRICA",
                 collection = "SENTINEL-2-L2A",
                 bands = c("B02", "B8A", "B11"),
-                tiles = c("37MDT","37MET"),
+                tiles = c("37MDT", "37MET"),
                 start_date = "2019-01-01",
                 end_date = "2019-08-28",
                 progress = FALSE
@@ -193,7 +192,7 @@ test_that("Creating S2 cubes from DEA using tiles", {
     )
 
     testthat::skip_if(purrr::is_null(dea_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(dea_cube) %in% c("B02", "B8A", "B11")))
@@ -201,7 +200,7 @@ test_that("Creating S2 cubes from DEA using tiles", {
     r <- .raster_open_rast(.tile_path(dea_cube))
     expect_equal(dea_cube$xmax[[1]], .raster_xmax(r), tolerance = 1)
     expect_equal(dea_cube$xmin[[1]], .raster_xmin(r), tolerance = 1)
-    expect_true(all(dea_cube$tile %in% c("37MDT","37MET")))
+    expect_true(all(dea_cube$tile %in% c("37MDT", "37MET")))
 })
 
 test_that("Creating Sentinel-1 RTC cubes from DEA using ROI", {
@@ -212,7 +211,7 @@ test_that("Creating Sentinel-1 RTC cubes from DEA using ROI", {
                 collection = "SENTINEL-1-RTC",
                 bands = c("VV"),
                 orbit = "descending",
-                roi   = c(
+                roi = c(
                     lon_min = 17.379,
                     lat_min = 1.1573,
                     lon_max = 17.410,
@@ -227,7 +226,7 @@ test_that("Creating Sentinel-1 RTC cubes from DEA using ROI", {
     )
 
     testthat::skip_if(purrr::is_null(cube_s1_rtc),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(sits_bands(cube_s1_rtc) == "VV")
@@ -255,7 +254,7 @@ test_that("Creating Sentinel-1 RTC cubes from DEA using tiles", {
     )
 
     testthat::skip_if(purrr::is_null(cube_s1_rtc),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     bbox <- sits_bbox(cube_s1_rtc)
@@ -267,8 +266,8 @@ test_that("Creating Sentinel-1 RTC cubes from DEA using tiles", {
     expect_true(bbox[["ymax"]] > roi_cube_s1[["ymax"]])
     expect_true(all(c("VV") %in% sits_bands(cube_s1_rtc)))
 
-    r_obj <- .raster_open_rast(cube_s1_rtc$file_info[[1]]$path[[1]])
-    expect_true(terra::nrow(r_obj) == cube_s1_rtc$file_info[[1]]$nrows[[1]])
+    rast <- .raster_open_rast(cube_s1_rtc$file_info[[1]]$path[[1]])
+    expect_true(.raster_nrows(rast) == cube_s1_rtc$file_info[[1]]$nrows[[1]])
 
     output_dir <- paste0(tempdir(), "/s1-rtc-reg")
     if (!dir.exists(output_dir)) {
@@ -282,7 +281,7 @@ test_that("Creating Sentinel-1 RTC cubes from DEA using tiles", {
         tiles = c("36NWJ"),
         multicores = 1,
         output_dir = output_dir,
-        progress = TRUE
+        progress = FALSE
     )
     expect_equal(length(sits_timeline(cube_s1_reg)), 2)
     expect_true("36NWJ" %in% cube_s1_reg$tile)
@@ -306,7 +305,7 @@ test_that("Creating Landsat-8/9 Geomedian (Annual) from DEA", {
                 source = "DEAFRICA",
                 collection = "GM-LS8-LS9-ANNUAL",
                 bands = c("B05"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -321,7 +320,7 @@ test_that("Creating Landsat-8/9 Geomedian (Annual) from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(landsat_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(landsat_cube) %in% c("B05")))
@@ -330,9 +329,9 @@ test_that("Creating Landsat-8/9 Geomedian (Annual) from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(landsat_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(landsat_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(landsat_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 test_that("Creating Sentinel-2 Geomedian (Annual) from DEA", {
     sentinel_cube <- .try(
@@ -341,7 +340,7 @@ test_that("Creating Sentinel-2 Geomedian (Annual) from DEA", {
                 source = "DEAFRICA",
                 collection = "GM-S2-ANNUAL",
                 bands = c("B05"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -356,7 +355,7 @@ test_that("Creating Sentinel-2 Geomedian (Annual) from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(sentinel_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(sentinel_cube) %in% c("B05")))
@@ -365,9 +364,9 @@ test_that("Creating Sentinel-2 Geomedian (Annual) from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(sentinel_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(sentinel_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(sentinel_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(sentinel_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 test_that("Creating Sentinel-2 Geomedian (Semiannual) from DEA", {
     sentinel_cube <- .try(
@@ -376,7 +375,7 @@ test_that("Creating Sentinel-2 Geomedian (Semiannual) from DEA", {
                 source = "DEAFRICA",
                 collection = "GM-S2-ANNUAL",
                 bands = c("B05"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -391,7 +390,7 @@ test_that("Creating Sentinel-2 Geomedian (Semiannual) from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(sentinel_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(sentinel_cube) %in% c("B05")))
@@ -400,9 +399,9 @@ test_that("Creating Sentinel-2 Geomedian (Semiannual) from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(sentinel_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(sentinel_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(sentinel_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(sentinel_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 test_that("Creating Sentinel-2 Geomedian (Rolling) from DEA", {
     sentinel_cube <- .try(
@@ -411,7 +410,7 @@ test_that("Creating Sentinel-2 Geomedian (Rolling) from DEA", {
                 source = "DEAFRICA",
                 collection = "GM-S2-ROLLING",
                 bands = c("B05", "B8A"),
-                roi   = c(
+                roi = c(
                     lon_min = 33.546,
                     lon_max = 34.999,
                     lat_min = 1.427,
@@ -426,7 +425,7 @@ test_that("Creating Sentinel-2 Geomedian (Rolling) from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(sentinel_cube),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(sentinel_cube) %in% c("B05", "B8A")))
@@ -435,9 +434,9 @@ test_that("Creating Sentinel-2 Geomedian (Rolling) from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(sentinel_cube), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(sentinel_cube$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(sentinel_cube$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(sentinel_cube)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating ALOS-PALSAR-MOSAIC cubes from DEA", {
@@ -447,7 +446,7 @@ test_that("Creating ALOS-PALSAR-MOSAIC cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "ALOS-PALSAR-MOSAIC",
                 bands = c("HH", "HV", "CLOUD"),
-                roi   = c(
+                roi = c(
                     lon_min = 17.379,
                     lat_min = 1.1573,
                     lon_max = 17.410,
@@ -462,7 +461,7 @@ test_that("Creating ALOS-PALSAR-MOSAIC cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(cube_alos),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(all(sits_bands(cube_alos) %in% c("HH", "HV", "CLOUD")))
@@ -471,9 +470,9 @@ test_that("Creating ALOS-PALSAR-MOSAIC cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(cube_alos), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(cube_alos$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(cube_alos$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(cube_alos)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating NDVI-ANOMALY cubes from DEA", {
@@ -483,7 +482,7 @@ test_that("Creating NDVI-ANOMALY cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "NDVI-ANOMALY",
                 bands = c("NDVI-MEAN"),
-                roi   = c(
+                roi = c(
                     lon_min = 17.379,
                     lat_min = 1.1573,
                     lon_max = 17.410,
@@ -498,7 +497,7 @@ test_that("Creating NDVI-ANOMALY cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(cube_ndvi),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(sits_bands(cube_ndvi) == "NDVI-MEAN")
@@ -507,9 +506,9 @@ test_that("Creating NDVI-ANOMALY cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(cube_ndvi), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(cube_ndvi$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(cube_ndvi$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(cube_ndvi)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating RAINFALL-CHIRPS-DAILY cubes from DEA", {
@@ -519,7 +518,7 @@ test_that("Creating RAINFALL-CHIRPS-DAILY cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "RAINFALL-CHIRPS-DAILY",
                 bands = c("RAINFALL"),
-                roi   = c(
+                roi = c(
                     lon_min = 17.379,
                     lat_min = 1.1573,
                     lon_max = 17.410,
@@ -534,7 +533,7 @@ test_that("Creating RAINFALL-CHIRPS-DAILY cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(cube_chirps),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(sits_bands(cube_chirps) == "RAINFALL")
@@ -543,9 +542,33 @@ test_that("Creating RAINFALL-CHIRPS-DAILY cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(cube_chirps), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(cube_chirps$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(cube_chirps$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(cube_chirps)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
+
+    # Create regularization directory
+    output_dir <- paste0(tempdir(), "/rainfall-daily-reg")
+    if (!dir.exists(output_dir)) {
+        dir.create(output_dir)
+    }
+
+    # Regularize
+    cube_chirps_reg <- suppressWarnings(
+        sits_regularize(
+            cube = cube_chirps,
+            period = "P1M",
+            res = 320,
+            tiles = c("36NWJ"),
+            multicores = 1,
+            output_dir = output_dir,
+            progress = FALSE
+        )
+    )
+
+    # Assert properties
+    expect_equal(length(sits_timeline(cube_chirps_reg)), 3)
+    expect_true("36NWJ" %in% cube_chirps_reg[["tile"]])
+    expect_true(all("EPSG:32636" %in% cube_chirps_reg[["crs"]]))
 })
 
 test_that("Creating RAINFALL-CHIRPS-MONTHLY cubes from DEA", {
@@ -555,7 +578,7 @@ test_that("Creating RAINFALL-CHIRPS-MONTHLY cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "RAINFALL-CHIRPS-MONTHLY",
                 bands = c("RAINFALL"),
-                roi   = c(
+                roi = c(
                     lon_min = 17.379,
                     lat_min = 1.1573,
                     lon_max = 17.410,
@@ -570,7 +593,7 @@ test_that("Creating RAINFALL-CHIRPS-MONTHLY cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(cube_chirps),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(sits_bands(cube_chirps) == "RAINFALL")
@@ -579,9 +602,9 @@ test_that("Creating RAINFALL-CHIRPS-MONTHLY cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(cube_chirps), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(cube_chirps$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(cube_chirps$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(cube_chirps)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
 
 test_that("Creating DEM-COP-30 cubes from DEA", {
@@ -591,7 +614,7 @@ test_that("Creating DEM-COP-30 cubes from DEA", {
                 source = "DEAFRICA",
                 collection = "DEM-COP-30",
                 bands = c("ELEVATION"),
-                roi   = c(
+                roi = c(
                     lon_min = 17.379,
                     lat_min = 1.1573,
                     lon_max = 17.410,
@@ -604,7 +627,7 @@ test_that("Creating DEM-COP-30 cubes from DEA", {
     )
 
     testthat::skip_if(purrr::is_null(cube_dem),
-                      message = "DEAFRICA is not accessible"
+        message = "DEAFRICA is not accessible"
     )
 
     expect_true(sits_bands(cube_dem) == "ELEVATION")
@@ -613,7 +636,7 @@ test_that("Creating DEM-COP-30 cubes from DEA", {
     bbox_cube_1 <- sits_bbox(.tile(cube_dem), as_crs = "EPSG:4326")
     expect_true(bbox_cube["xmax"] >= bbox_cube_1["xmax"])
     expect_true(bbox_cube["ymax"] >= bbox_cube_1["ymax"])
-    r_obj <- .raster_open_rast(cube_dem$file_info[[1]]$path[1])
+    rast <- .raster_open_rast(cube_dem$file_info[[1]]$path[1])
     cube_nrows <- .tile_nrows(cube_dem)
-    expect_true(.raster_nrows(r_obj) == cube_nrows)
+    expect_true(.raster_nrows(rast) == cube_nrows)
 })
